[MPlayer-cvslog] r29252 - in trunk: AUTHORS DOCS/man/cs/mplayer.1 DOCS/man/de/mplayer.1 DOCS/man/en/mplayer.1 DOCS/man/es/mplayer.1 DOCS/man/fr/mplayer.1 DOCS/man/hu/mplayer.1 DOCS/man/it/mplayer.1 DOCS/man/pl/mpla...

diego subversion at mplayerhq.hu
Mon May 4 18:55:06 CEST 2009


Author: diego
Date: Mon May  4 18:55:05 2009
New Revision: 29252

Log:
Rename macosx video output driver to corevideo.

Added:
   trunk/libvo/vo_corevideo.h
      - copied, changed from r29251, trunk/libvo/vo_macosx.h
   trunk/libvo/vo_corevideo.m
      - copied, changed from r29251, trunk/libvo/vo_macosx.m
Deleted:
   trunk/libvo/vo_macosx.h
   trunk/libvo/vo_macosx.m
Modified:
   trunk/AUTHORS
   trunk/DOCS/tech/MAINTAINERS
   trunk/Makefile
   trunk/configure
   trunk/libvo/video_out.c

Changes in other areas also in this revision:
Modified:
   trunk/DOCS/man/cs/mplayer.1
   trunk/DOCS/man/de/mplayer.1
   trunk/DOCS/man/en/mplayer.1
   trunk/DOCS/man/es/mplayer.1
   trunk/DOCS/man/fr/mplayer.1
   trunk/DOCS/man/hu/mplayer.1
   trunk/DOCS/man/it/mplayer.1
   trunk/DOCS/man/pl/mplayer.1
   trunk/DOCS/man/ru/mplayer.1
   trunk/DOCS/man/zh_CN/mplayer.1
   trunk/DOCS/xml/cs/ports.xml
   trunk/DOCS/xml/de/ports.xml
   trunk/DOCS/xml/en/ports.xml
   trunk/DOCS/xml/fr/ports.xml
   trunk/DOCS/xml/hu/ports.xml
   trunk/DOCS/xml/pl/ports.xml
   trunk/DOCS/xml/ru/ports.xml

Modified: trunk/AUTHORS
==============================================================================
--- trunk/AUTHORS	Mon May  4 16:53:47 2009	(r29251)
+++ trunk/AUTHORS	Mon May  4 18:55:05 2009	(r29252)
@@ -637,7 +637,7 @@ Pietrzak, Dariusz (Eyck) <eyck at ghost.ani
 
 Plourde, Nicolas <nicolas.plourde at gmail.com>
     * quartz video output driver for Mac OS X
-    * macosx CoreVideo output driver for Mac OS X
+    * CoreVideo video output driver for Mac OS X
     * Darwin VCD/SVCD support
 
 Poettering, Lennart <mzzcynlre at 0pointer.de>

Modified: trunk/DOCS/tech/MAINTAINERS
==============================================================================
--- trunk/DOCS/tech/MAINTAINERS	Mon May  4 16:53:47 2009	(r29251)
+++ trunk/DOCS/tech/MAINTAINERS	Mon May  4 18:55:05 2009	(r29252)
@@ -156,6 +156,7 @@ libvo drivers:
     * vo_aa.c - Alban Bedel
     * vo_caca.c - Howell Tam (Pigeon)
     * vo_bl.c - Rik Snel
+    * vo_corevideo.m - None
     * vo_cvidix.c - Sascha Sommer
     * vo_dga.c - None
     * vo_dfbmga.c - Ville Syrjälä
@@ -172,7 +173,6 @@ libvo drivers:
     * vo_gl2.c - Reimar Döffinger
     * vo_ivtv.c - Benjamin Zores
     * vo_jpeg.c - Ivo van Poorten
-    * vo_macosx.m - None
     * vo_md5sum.c - Ivo van Poorten
     * vo_mga.c - Attila Kinali
     * vo_mpegpes.c - None

Modified: trunk/Makefile
==============================================================================
--- trunk/Makefile	Mon May  4 16:53:47 2009	(r29251)
+++ trunk/Makefile	Mon May  4 18:55:05 2009	(r29252)
@@ -532,7 +532,7 @@ SRCS_MPLAYER-$(ARTS)         += libao2/a
 SRCS_MPLAYER-$(BL)           += libvo/vo_bl.c
 SRCS_MPLAYER-$(CACA)         += libvo/vo_caca.c
 SRCS_MPLAYER-$(COREAUDIO)    += libao2/ao_coreaudio.c
-SRCS_MPLAYER-$(COREVIDEO)    += libvo/vo_macosx.m
+SRCS_MPLAYER-$(COREVIDEO)    += libvo/vo_corevideo.m
 SRCS_MPLAYER-$(DART)         += libao2/ao_dart.c
 SRCS_MPLAYER-$(DFBMGA)       += libvo/vo_dfbmga.c
 SRCS_MPLAYER-$(DGA)          += libvo/vo_dga.c

Modified: trunk/configure
==============================================================================
--- trunk/configure	Mon May  4 16:53:47 2009	(r29251)
+++ trunk/configure	Mon May  4 18:55:05 2009	(r29252)
@@ -3863,11 +3863,11 @@ EOF
   cc_check -framework Carbon -framework Cocoa -framework QuartzCore -framework OpenGL && _corevideo=yes
 fi
 if test "$_corevideo" = yes ; then
-  _vomodules="macosx $_vomodules"
+  _vomodules="corevideo $_vomodules"
   extra_ldflags="$extra_ldflags -framework Carbon -framework Cocoa -framework QuartzCore -framework OpenGL"
   def_corevideo='#define CONFIG_COREVIDEO 1'
 else
-  _novomodules="macosx $_novomodules"
+  _novomodules="corevideo $_novomodules"
   def_corevideo='#undef CONFIG_COREVIDEO'
 fi
 echores "$_corevideo"

Modified: trunk/libvo/video_out.c
==============================================================================
--- trunk/libvo/video_out.c	Mon May  4 16:53:47 2009	(r29251)
+++ trunk/libvo/video_out.c	Mon May  4 18:55:05 2009	(r29252)
@@ -128,7 +128,7 @@ extern vo_functions_t video_out_cvidix;
 extern vo_functions_t video_out_tdfx_vid;
 extern vo_functions_t video_out_xvr100;
 extern vo_functions_t video_out_tga;
-extern vo_functions_t video_out_macosx;
+extern vo_functions_t video_out_corevideo;
 extern vo_functions_t video_out_quartz;
 extern vo_functions_t video_out_pnm;
 extern vo_functions_t video_out_md5sum;
@@ -151,7 +151,7 @@ const vo_functions_t* const video_out_dr
         &video_out_kva,
 #endif
 #ifdef CONFIG_COREVIDEO
-        &video_out_macosx,
+        &video_out_corevideo,
 #endif
 #ifdef CONFIG_QUARTZ
         &video_out_quartz,

Copied and modified: trunk/libvo/vo_corevideo.h (from r29251, trunk/libvo/vo_macosx.h)
==============================================================================
--- trunk/libvo/vo_macosx.h	Mon May  4 16:53:47 2009	(r29251, copy source)
+++ trunk/libvo/vo_corevideo.h	Mon May  4 18:55:05 2009	(r29252)
@@ -1,5 +1,5 @@
 /*
- * MPlayer Mac OS X video output driver
+ * CoreVideo video output driver
  *
  * Copyright (c) 2005 Nicolas Plourde <nicolasplourde at gmail.com>
  *

Copied and modified: trunk/libvo/vo_corevideo.m (from r29251, trunk/libvo/vo_macosx.m)
==============================================================================
--- trunk/libvo/vo_macosx.m	Mon May  4 16:53:47 2009	(r29251, copy source)
+++ trunk/libvo/vo_corevideo.m	Mon May  4 18:55:05 2009	(r29252)
@@ -1,5 +1,5 @@
 /*
  * Mac OS X video output driver
  * Copyright (c) 2005 Nicolas Plourde <nicolasplourde at gmail.com>
  *
  * This file is part of MPlayer.
@@ -19,7 +19,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#import "vo_macosx.h"
+#import "vo_corevideo.h"
 #include <sys/types.h>
 #include <sys/ipc.h>
 #include <sys/mman.h>
@@ -96,12 +96,12 @@ static BOOL isLeopardOrLater;
 static vo_info_t info = 
 {
 	"Mac OS X Core Video",
-	"macosx",
+	"corevideo",
 	"Nicolas Plourde <nicolas.plourde at gmail.com>",
 	""
 };
 
-LIBVO_EXTERN(macosx)
+LIBVO_EXTERN(corevideo)
 
 static void draw_alpha(int x0, int y0, int w, int h, unsigned char *src, unsigned char *srca, int stride)
 {
@@ -127,7 +127,7 @@ static int config(uint32_t width, uint32
 	}
 	else
 	{
-		mp_msg(MSGT_VO, MSGL_INFO, "[vo_macosx] Device ID %d does not exist, falling back to main device\n", screen_id);
+		mp_msg(MSGT_VO, MSGL_INFO, "[vo_corevideo] Device ID %d does not exist, falling back to main device\n", screen_id);
 		screen_handle = [screen_array objectAtIndex:0];
 		screen_id = -1;
 	}
@@ -178,7 +178,7 @@ static int config(uint32_t width, uint32
 	}
 	else
 	{
-		mp_msg(MSGT_VO, MSGL_INFO, "[vo_macosx] writing output to a shared buffer "
+		mp_msg(MSGT_VO, MSGL_INFO, "[vo_corevideo] writing output to a shared buffer "
 				"named \"%s\"\n",buffer_name);
 		
 		movie_aspect = (float)d_width/(float)d_height;
@@ -188,7 +188,7 @@ static int config(uint32_t width, uint32
 		if (shm_fd == -1)
 		{
 			mp_msg(MSGT_VO, MSGL_FATAL, 
-				   "[vo_macosx] failed to open shared memory. Error: %s\n", strerror(errno));
+				   "[vo_corevideo] failed to open shared memory. Error: %s\n", strerror(errno));
 			return 1;
 		}
 		
@@ -196,7 +196,7 @@ static int config(uint32_t width, uint32
 		if (ftruncate(shm_fd, image_width*image_height*image_bytes) == -1)
 		{
 			mp_msg(MSGT_VO, MSGL_FATAL, 
-				   "[vo_macosx] failed to size shared memory, possibly already in use. Error: %s\n", strerror(errno));
+				   "[vo_corevideo] failed to size shared memory, possibly already in use. Error: %s\n", strerror(errno));
 			shm_unlink(buffer_name);
 			return 1;
 		}
@@ -207,7 +207,7 @@ static int config(uint32_t width, uint32
 		if (image_data == MAP_FAILED)
 		{
 			mp_msg(MSGT_VO, MSGL_FATAL, 
-				   "[vo_macosx] failed to map shared memory. Error: %s\n", strerror(errno));
+				   "[vo_corevideo] failed to map shared memory. Error: %s\n", strerror(errno));
 			shm_unlink(buffer_name);
 			return 1;
 		}		
@@ -303,10 +303,10 @@ static void uninit(void)
 		mplayerosxProxy = nil;
 		
 		if (munmap(image_data, image_width*image_height*image_bytes) == -1)
-			mp_msg(MSGT_VO, MSGL_FATAL, "[vo_macosx] uninit: munmap failed. Error: %s\n", strerror(errno));
+			mp_msg(MSGT_VO, MSGL_FATAL, "[vo_corevideo] uninit: munmap failed. Error: %s\n", strerror(errno));
 		
 		if (shm_unlink(buffer_name) == -1)
-			mp_msg(MSGT_VO, MSGL_FATAL, "[vo_macosx] uninit: shm_unlink failed. Error: %s\n", strerror(errno));
+			mp_msg(MSGT_VO, MSGL_FATAL, "[vo_corevideo] uninit: shm_unlink failed. Error: %s\n", strerror(errno));
 		
 	}
 
@@ -353,8 +353,8 @@ static int preinit(const char *arg)
 	
 	if (subopt_parse(arg, subopts) != 0) {
 		mp_msg(MSGT_VO, MSGL_FATAL,
-				"\n-vo macosx command line help:\n"
-				"Example: mplayer -vo macosx:device_id=1:shared_buffer:buffer_name=mybuff\n"
+				"\n-vo corevideo command line help:\n"
+				"Example: mplayer -vo corevideo:device_id=1:shared_buffer:buffer_name=mybuff\n"
 				"\nOptions:\n"
 				"  device_id=<0-...>\n"
 				"    Set screen device ID for fullscreen.\n"
@@ -477,20 +477,20 @@ static int control(uint32_t request, voi
 	
 	error = CVPixelBufferCreateWithBytes(NULL, image_width, image_height, pixelFormat, image_datas[0], image_width*image_bytes, NULL, NULL, NULL, &frameBuffers[0]);
 	if(error != kCVReturnSuccess)
-		mp_msg(MSGT_VO, MSGL_ERR,"[vo_macosx] Failed to create Pixel Buffer(%d)\n", error);
+		mp_msg(MSGT_VO, MSGL_ERR,"[vo_corevideo] Failed to create Pixel Buffer(%d)\n", error);
 	if (vo_doublebuffering) {
 		error = CVPixelBufferCreateWithBytes(NULL, image_width, image_height, pixelFormat, image_datas[1], image_width*image_bytes, NULL, NULL, NULL, &frameBuffers[1]);
 		if(error != kCVReturnSuccess)
-			mp_msg(MSGT_VO, MSGL_ERR,"[vo_macosx] Failed to create Pixel Double Buffer(%d)\n", error);
+			mp_msg(MSGT_VO, MSGL_ERR,"[vo_corevideo] Failed to create Pixel Double Buffer(%d)\n", error);
 	}
 	
 	error = CVOpenGLTextureCacheCreate(NULL, 0, [glContext CGLContextObj], [[self pixelFormat] CGLPixelFormatObj], 0, &textureCache);
 	if(error != kCVReturnSuccess)
-		mp_msg(MSGT_VO, MSGL_ERR,"[vo_macosx] Failed to create OpenGL texture Cache(%d)\n", error);
+		mp_msg(MSGT_VO, MSGL_ERR,"[vo_corevideo] Failed to create OpenGL texture Cache(%d)\n", error);
 	
 	error = CVOpenGLTextureCacheCreateTextureFromImage(NULL, textureCache, frameBuffers[image_page], 0, &texture);
 	if(error != kCVReturnSuccess)
-		mp_msg(MSGT_VO, MSGL_ERR,"[vo_macosx] Failed to create OpenGL texture(%d)\n", error);
+		mp_msg(MSGT_VO, MSGL_ERR,"[vo_corevideo] Failed to create OpenGL texture(%d)\n", error);
 	
 	//show window
 	[window center];
@@ -838,7 +838,7 @@ static int control(uint32_t request, voi
 	CVOpenGLTextureRelease(texture);
 	error = CVOpenGLTextureCacheCreateTextureFromImage(NULL, textureCache, frameBuffers[image_page], 0, &texture);
 	if(error != kCVReturnSuccess)
-		mp_msg(MSGT_VO, MSGL_ERR,"[vo_macosx] Failed to create OpenGL texture(%d)\n", error);
+		mp_msg(MSGT_VO, MSGL_ERR,"[vo_corevideo] Failed to create OpenGL texture(%d)\n", error);
 
     CVOpenGLTextureGetCleanTexCoords(texture, lowerLeft, lowerRight, upperRight, upperLeft);
 }
@@ -1,5 +1,5 @@
 /*
- * Mac OS X video output driver
+ * CoreVideo video output driver
  * Copyright (c) 2005 Nicolas Plourde <nicolasplourde at gmail.com>
  *


More information about the MPlayer-cvslog mailing list